@@ -95,7 +95,7 @@ module Aws::S3
       options, params = separate_params_and_options(options)
       waiter = Waiters::BucketExists.new(options)
       yield_waiter_and_warn(waiter, &block) if block_given?
-      Aws::Plugins::UserAgent.feature('resource') do
+      Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         waiter.wait(params.merge(bucket: @name))
       end
       Bucket.new({
@@ -114,7 +114,7 @@ module Aws::S3
       options, params = separate_params_and_options(options)
       waiter = Waiters::BucketNotExists.new(options)
       yield_waiter_and_warn(waiter, &block) if block_given?
-      Aws::Plugins::UserAgent.feature('resource') do
+      Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         waiter.wait(params.merge(bucket: @name))
       end
       Bucket.new({
@@ -217,7 +217,7 @@ module Aws::S3
           :retry
         end
       end
-      Aws::Plugins::UserAgent.feature('resource') do
+      Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         Aws::Waiters::Waiter.new(options).wait({})
       end
     end
@@ -334,7 +334,7 @@ module Aws::S3
     # @return [Types::CreateBucketOutput]
     def create(options = {})
       options = options.merge(bucket: @name)
-      resp = Aws::Plugins::UserAgent.feature('resource') do
+      resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         @client.create_bucket(options)
       end
       resp.data
@@ -359,7 +359,7 @@ module Aws::S3
     # @return [EmptyStructure]
     def delete(options = {})
       options = options.merge(bucket: @name)
-      resp = Aws::Plugins::UserAgent.feature('resource') do
+      resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         @client.delete_bucket(options)
       end
       resp.data
@@ -473,7 +473,7 @@ module Aws::S3
     # @return [Types::DeleteObjectsOutput]
     def delete_objects(options = {})
       options = options.merge(bucket: @name)
-      resp = Aws::Plugins::UserAgent.feature('resource') do
+      resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         @client.delete_objects(options)
       end
       resp.data
@@ -939,7 +939,7 @@ module Aws::S3
     # @return [Object]
     def put_object(options = {})
       options = options.merge(bucket: @name)
-      Aws::Plugins::UserAgent.feature('resource') do
+      Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         @client.put_object(options)
       end
       Object.new(
@@ -1097,7 +1097,7 @@ module Aws::S3
     def multipart_uploads(options = {})
       batches = Enumerator.new do |y|
         options = options.merge(bucket: @name)
-        resp = Aws::Plugins::UserAgent.feature('resource') do
+        resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
           @client.list_multipart_uploads(options)
         end
         resp.each_page do |page|
@@ -1200,7 +1200,7 @@ module Aws::S3
     def object_versions(options = {})
       batches = Enumerator.new do |y|
         options = options.merge(bucket: @name)
-        resp = Aws::Plugins::UserAgent.feature('resource') do
+        resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
           @client.list_object_versions(options)
         end
         resp.each_page do |page|
@@ -1253,6 +1253,9 @@ module Aws::S3
     #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuoverview.html
     # @option options [String] :encoding_type
     #   Encoding type used by Amazon S3 to encode object keys in the response.
+    #   If using `url`, non-ASCII characters used in an object's key name
+    #   will be URL encoded. For example, the object test\_file(3).png will
+    #   appear as test\_file%283%29.png.
     # @option options [String] :prefix
     #   Limits the response to keys that begin with the specified prefix.
     #
@@ -1300,7 +1303,7 @@ module Aws::S3
     def objects(options = {})
       batches = Enumerator.new do |y|
         options = options.merge(bucket: @name)
-        resp = Aws::Plugins::UserAgent.feature('resource') do
+        resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
           @client.list_objects_v2(options)
         end
         resp.each_page do |page|
