@@ -93,7 +93,7 @@ module Aws::S3
       data[:is_latest]
     end
 
-    # Date and time the object was last modified.
+    # Date and time when the object was last modified.
     # @return [Time]
     def last_modified
       data[:last_modified]
@@ -105,6 +105,20 @@ module Aws::S3
       data[:owner]
     end
 
+    # Specifies the restoration status of an object. Objects in certain
+    # storage classes must be restored before they can be retrieved. For
+    # more information about these storage classes and how to work with
+    # archived objects, see [ Working with archived objects][1] in the
+    # *Amazon S3 User Guide*.
+    #
+    #
+    #
+    # [1]: https://docs.aws.amazon.com/AmazonS3/latest/userguide/archived-objects.html
+    # @return [Types::RestoreStatus]
+    def restore_status
+      data[:restore_status]
+    end
+
     # @!endgroup
 
     # @return [Client]
@@ -229,7 +243,9 @@ module Aws::S3
           :retry
         end
       end
-      Aws::Waiters::Waiter.new(options).wait({})
+      Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
+        Aws::Waiters::Waiter.new(options).wait({})
+      end
     end
 
     # @!group Actions
@@ -248,13 +264,23 @@ module Aws::S3
     #   space, and the value that is displayed on your authentication device.
     #   Required to permanently delete a versioned object if versioning is
     #   configured with MFA delete enabled.
+    #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
     # @option options [String] :request_payer
     #   Confirms that the requester knows that they will be charged for the
     #   request. Bucket owners need not specify this parameter in their
-    #   requests. For information about downloading objects from Requester
+    #   requests. If either the source or destination S3 bucket has Requester
+    #   Pays enabled, the requester will pay for corresponding charges to copy
+    #   the object. For information about downloading objects from Requester
     #   Pays buckets, see [Downloading Objects in Requester Pays Buckets][1]
     #   in the *Amazon S3 User Guide*.
     #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
+    #
     #
     #
     #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html
@@ -262,10 +288,14 @@ module Aws::S3
     #   Indicates whether S3 Object Lock should bypass Governance-mode
     #   restrictions to process this operation. To use this header, you must
     #   have the `s3:BypassGovernanceRetention` permission.
+    #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
     # @option options [String] :expected_bucket_owner
-    #   The account ID of the expected bucket owner. If the bucket is owned by
-    #   a different account, the request fails with the HTTP status code `403
-    #   Forbidden` (access denied).
+    #   The account ID of the expected bucket owner. If the account ID that
+    #   you provide does not match the actual owner of the bucket, the request
+    #   fails with the HTTP status code `403 Forbidden` (access denied).
     # @return [Types::DeleteObjectOutput]
     def delete(options = {})
       options = options.merge(
@@ -273,7 +303,9 @@ module Aws::S3
         key: @object_key,
         version_id: @id
       )
-      resp = @client.delete_object(options)
+      resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
+        @client.delete_object(options)
+      end
       resp.data
     end
 
@@ -302,20 +334,66 @@ module Aws::S3
     # @param [Hash] options ({})
     # @option options [String] :if_match
     #   Return the object only if its entity tag (ETag) is the same as the one
-    #   specified; otherwise, return a 412 (precondition failed) error.
+    #   specified in this header; otherwise, return a `412 Precondition
+    #   Failed` error.
+    #
+    #   If both of the `If-Match` and `If-Unmodified-Since` headers are
+    #   present in the request as follows: `If-Match` condition evaluates to
+    #   `true`, and; `If-Unmodified-Since` condition evaluates to `false`;
+    #   then, S3 returns `200 OK` and the data requested.
+    #
+    #   For more information about conditional requests, see [RFC 7232][1].
+    #
+    #
+    #
+    #   [1]: https://tools.ietf.org/html/rfc7232
     # @option options [Time,DateTime,Date,Integer,String] :if_modified_since
     #   Return the object only if it has been modified since the specified
-    #   time; otherwise, return a 304 (not modified) error.
+    #   time; otherwise, return a `304 Not Modified` error.
+    #
+    #   If both of the `If-None-Match` and `If-Modified-Since` headers are
+    #   present in the request as follows:` If-None-Match` condition evaluates
+    #   to `false`, and; `If-Modified-Since` condition evaluates to `true`;
+    #   then, S3 returns `304 Not Modified` status code.
+    #
+    #   For more information about conditional requests, see [RFC 7232][1].
+    #
+    #
+    #
+    #   [1]: https://tools.ietf.org/html/rfc7232
     # @option options [String] :if_none_match
     #   Return the object only if its entity tag (ETag) is different from the
-    #   one specified; otherwise, return a 304 (not modified) error.
+    #   one specified in this header; otherwise, return a `304 Not Modified`
+    #   error.
+    #
+    #   If both of the `If-None-Match` and `If-Modified-Since` headers are
+    #   present in the request as follows:` If-None-Match` condition evaluates
+    #   to `false`, and; `If-Modified-Since` condition evaluates to `true`;
+    #   then, S3 returns `304 Not Modified` HTTP status code.
+    #
+    #   For more information about conditional requests, see [RFC 7232][1].
+    #
+    #
+    #
+    #   [1]: https://tools.ietf.org/html/rfc7232
     # @option options [Time,DateTime,Date,Integer,String] :if_unmodified_since
     #   Return the object only if it has not been modified since the specified
-    #   time; otherwise, return a 412 (precondition failed) error.
+    #   time; otherwise, return a `412 Precondition Failed` error.
+    #
+    #   If both of the `If-Match` and `If-Unmodified-Since` headers are
+    #   present in the request as follows: `If-Match` condition evaluates to
+    #   `true`, and; `If-Unmodified-Since` condition evaluates to `false`;
+    #   then, S3 returns `200 OK` and the data requested.
+    #
+    #   For more information about conditional requests, see [RFC 7232][1].
+    #
+    #
+    #
+    #   [1]: https://tools.ietf.org/html/rfc7232
     # @option options [String] :range
-    #   Downloads the specified range bytes of an object. For more information
+    #   Downloads the specified byte range of an object. For more information
     #   about the HTTP Range header, see
-    #   [https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.35][1].
+    #   [https://www.rfc-editor.org/rfc/rfc9110.html#name-range][1].
     #
     #   <note markdown="1"> Amazon S3 doesn't support retrieving multiple ranges of data per
     #   `GET` request.
@@ -324,11 +402,11 @@ module Aws::S3
     #
     #
     #
-    #   [1]: https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.35
+    #   [1]: https://www.rfc-editor.org/rfc/rfc9110.html#name-range
     # @option options [String] :response_cache_control
     #   Sets the `Cache-Control` header of the response.
     # @option options [String] :response_content_disposition
-    #   Sets the `Content-Disposition` header of the response
+    #   Sets the `Content-Disposition` header of the response.
     # @option options [String] :response_content_encoding
     #   Sets the `Content-Encoding` header of the response.
     # @option options [String] :response_content_language
@@ -338,25 +416,99 @@ module Aws::S3
     # @option options [Time,DateTime,Date,Integer,String] :response_expires
     #   Sets the `Expires` header of the response.
     # @option options [String] :sse_customer_algorithm
-    #   Specifies the algorithm to use to when decrypting the object (for
-    #   example, AES256).
+    #   Specifies the algorithm to use when decrypting the object (for
+    #   example, `AES256`).
+    #
+    #   If you encrypt an object by using server-side encryption with
+    #   customer-provided encryption keys (SSE-C) when you store the object in
+    #   Amazon S3, then when you GET the object, you must use the following
+    #   headers:
+    #
+    #   * `x-amz-server-side-encryption-customer-algorithm`
+    #
+    #   * `x-amz-server-side-encryption-customer-key`
+    #
+    #   * `x-amz-server-side-encryption-customer-key-MD5`
+    #
+    #   For more information about SSE-C, see [Server-Side Encryption (Using
+    #   Customer-Provided Encryption Keys)][1] in the *Amazon S3 User Guide*.
+    #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
+    #
+    #
+    #
+    #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/ServerSideEncryptionCustomerKeys.html
     # @option options [String] :sse_customer_key
-    #   Specifies the customer-provided encryption key for Amazon S3 used to
-    #   encrypt the data. This value is used to decrypt the object when
-    #   recovering it and must match the one used when storing the data. The
-    #   key must be appropriate for use with the algorithm specified in the
+    #   Specifies the customer-provided encryption key that you originally
+    #   provided for Amazon S3 to encrypt the data before storing it. This
+    #   value is used to decrypt the object when recovering it and must match
+    #   the one used when storing the data. The key must be appropriate for
+    #   use with the algorithm specified in the
     #   `x-amz-server-side-encryption-customer-algorithm` header.
+    #
+    #   If you encrypt an object by using server-side encryption with
+    #   customer-provided encryption keys (SSE-C) when you store the object in
+    #   Amazon S3, then when you GET the object, you must use the following
+    #   headers:
+    #
+    #   * `x-amz-server-side-encryption-customer-algorithm`
+    #
+    #   * `x-amz-server-side-encryption-customer-key`
+    #
+    #   * `x-amz-server-side-encryption-customer-key-MD5`
+    #
+    #   For more information about SSE-C, see [Server-Side Encryption (Using
+    #   Customer-Provided Encryption Keys)][1] in the *Amazon S3 User Guide*.
+    #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
+    #
+    #
+    #
+    #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/ServerSideEncryptionCustomerKeys.html
     # @option options [String] :sse_customer_key_md5
-    #   Specifies the 128-bit MD5 digest of the encryption key according to
-    #   RFC 1321. Amazon S3 uses this header for a message integrity check to
-    #   ensure that the encryption key was transmitted without error.
+    #   Specifies the 128-bit MD5 digest of the customer-provided encryption
+    #   key according to RFC 1321. Amazon S3 uses this header for a message
+    #   integrity check to ensure that the encryption key was transmitted
+    #   without error.
+    #
+    #   If you encrypt an object by using server-side encryption with
+    #   customer-provided encryption keys (SSE-C) when you store the object in
+    #   Amazon S3, then when you GET the object, you must use the following
+    #   headers:
+    #
+    #   * `x-amz-server-side-encryption-customer-algorithm`
+    #
+    #   * `x-amz-server-side-encryption-customer-key`
+    #
+    #   * `x-amz-server-side-encryption-customer-key-MD5`
+    #
+    #   For more information about SSE-C, see [Server-Side Encryption (Using
+    #   Customer-Provided Encryption Keys)][1] in the *Amazon S3 User Guide*.
+    #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
+    #
+    #
+    #
+    #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/ServerSideEncryptionCustomerKeys.html
     # @option options [String] :request_payer
     #   Confirms that the requester knows that they will be charged for the
     #   request. Bucket owners need not specify this parameter in their
-    #   requests. For information about downloading objects from Requester
+    #   requests. If either the source or destination S3 bucket has Requester
+    #   Pays enabled, the requester will pay for corresponding charges to copy
+    #   the object. For information about downloading objects from Requester
     #   Pays buckets, see [Downloading Objects in Requester Pays Buckets][1]
     #   in the *Amazon S3 User Guide*.
     #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
+    #
     #
     #
     #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html
@@ -366,9 +518,9 @@ module Aws::S3
     #   for the part specified. Useful for downloading just a part of an
     #   object.
     # @option options [String] :expected_bucket_owner
-    #   The account ID of the expected bucket owner. If the bucket is owned by
-    #   a different account, the request fails with the HTTP status code `403
-    #   Forbidden` (access denied).
+    #   The account ID of the expected bucket owner. If the account ID that
+    #   you provide does not match the actual owner of the bucket, the request
+    #   fails with the HTTP status code `403 Forbidden` (access denied).
     # @option options [String] :checksum_mode
     #   To retrieve the checksum, this mode must be enabled.
     # @return [Types::GetObjectOutput]
@@ -378,7 +530,9 @@ module Aws::S3
         key: @object_key,
         version_id: @id
       )
-      resp = @client.get_object(options, &block)
+      resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
+        @client.get_object(options, &block)
+      end
       resp.data
     end
 
@@ -402,38 +556,118 @@ module Aws::S3
     # @option options [String] :if_match
     #   Return the object only if its entity tag (ETag) is the same as the one
     #   specified; otherwise, return a 412 (precondition failed) error.
+    #
+    #   If both of the `If-Match` and `If-Unmodified-Since` headers are
+    #   present in the request as follows:
+    #
+    #   * `If-Match` condition evaluates to `true`, and;
+    #
+    #   * `If-Unmodified-Since` condition evaluates to `false`;
+    #
+    #   Then Amazon S3 returns `200 OK` and the data requested.
+    #
+    #   For more information about conditional requests, see [RFC 7232][1].
+    #
+    #
+    #
+    #   [1]: https://tools.ietf.org/html/rfc7232
     # @option options [Time,DateTime,Date,Integer,String] :if_modified_since
     #   Return the object only if it has been modified since the specified
     #   time; otherwise, return a 304 (not modified) error.
+    #
+    #   If both of the `If-None-Match` and `If-Modified-Since` headers are
+    #   present in the request as follows:
+    #
+    #   * `If-None-Match` condition evaluates to `false`, and;
+    #
+    #   * `If-Modified-Since` condition evaluates to `true`;
+    #
+    #   Then Amazon S3 returns the `304 Not Modified` response code.
+    #
+    #   For more information about conditional requests, see [RFC 7232][1].
+    #
+    #
+    #
+    #   [1]: https://tools.ietf.org/html/rfc7232
     # @option options [String] :if_none_match
     #   Return the object only if its entity tag (ETag) is different from the
     #   one specified; otherwise, return a 304 (not modified) error.
+    #
+    #   If both of the `If-None-Match` and `If-Modified-Since` headers are
+    #   present in the request as follows:
+    #
+    #   * `If-None-Match` condition evaluates to `false`, and;
+    #
+    #   * `If-Modified-Since` condition evaluates to `true`;
+    #
+    #   Then Amazon S3 returns the `304 Not Modified` response code.
+    #
+    #   For more information about conditional requests, see [RFC 7232][1].
+    #
+    #
+    #
+    #   [1]: https://tools.ietf.org/html/rfc7232
     # @option options [Time,DateTime,Date,Integer,String] :if_unmodified_since
     #   Return the object only if it has not been modified since the specified
     #   time; otherwise, return a 412 (precondition failed) error.
+    #
+    #   If both of the `If-Match` and `If-Unmodified-Since` headers are
+    #   present in the request as follows:
+    #
+    #   * `If-Match` condition evaluates to `true`, and;
+    #
+    #   * `If-Unmodified-Since` condition evaluates to `false`;
+    #
+    #   Then Amazon S3 returns `200 OK` and the data requested.
+    #
+    #   For more information about conditional requests, see [RFC 7232][1].
+    #
+    #
+    #
+    #   [1]: https://tools.ietf.org/html/rfc7232
     # @option options [String] :range
-    #   Because `HeadObject` returns only the metadata for an object, this
-    #   parameter has no effect.
+    #   HeadObject returns only the metadata for an object. If the Range is
+    #   satisfiable, only the `ContentLength` is affected in the response. If
+    #   the Range is not satisfiable, S3 returns a `416 - Requested Range Not
+    #   Satisfiable` error.
     # @option options [String] :sse_customer_algorithm
-    #   Specifies the algorithm to use to when encrypting the object (for
+    #   Specifies the algorithm to use when encrypting the object (for
     #   example, AES256).
+    #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
     # @option options [String] :sse_customer_key
     #   Specifies the customer-provided encryption key for Amazon S3 to use in
     #   encrypting data. This value is used to store the object and then it is
     #   discarded; Amazon S3 does not store the encryption key. The key must
     #   be appropriate for use with the algorithm specified in the
     #   `x-amz-server-side-encryption-customer-algorithm` header.
+    #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
     # @option options [String] :sse_customer_key_md5
     #   Specifies the 128-bit MD5 digest of the encryption key according to
     #   RFC 1321. Amazon S3 uses this header for a message integrity check to
     #   ensure that the encryption key was transmitted without error.
+    #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
     # @option options [String] :request_payer
     #   Confirms that the requester knows that they will be charged for the
     #   request. Bucket owners need not specify this parameter in their
-    #   requests. For information about downloading objects from Requester
+    #   requests. If either the source or destination S3 bucket has Requester
+    #   Pays enabled, the requester will pay for corresponding charges to copy
+    #   the object. For information about downloading objects from Requester
     #   Pays buckets, see [Downloading Objects in Requester Pays Buckets][1]
     #   in the *Amazon S3 User Guide*.
     #
+    #   <note markdown="1"> This functionality is not supported for directory buckets.
+    #
+    #    </note>
+    #
     #
     #
     #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html
@@ -443,9 +677,9 @@ module Aws::S3
     #   for the part specified. Useful querying about the size of the part and
     #   the number of parts in this object.
     # @option options [String] :expected_bucket_owner
-    #   The account ID of the expected bucket owner. If the bucket is owned by
-    #   a different account, the request fails with the HTTP status code `403
-    #   Forbidden` (access denied).
+    #   The account ID of the expected bucket owner. If the account ID that
+    #   you provide does not match the actual owner of the bucket, the request
+    #   fails with the HTTP status code `403 Forbidden` (access denied).
     # @option options [String] :checksum_mode
     #   To retrieve the checksum, this parameter must be enabled.
     #
@@ -460,7 +694,9 @@ module Aws::S3
         key: @object_key,
         version_id: @id
       )
-      resp = @client.head_object(options)
+      resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
+        @client.head_object(options)
+      end
       resp.data
     end
 
@@ -540,13 +776,36 @@ module Aws::S3
       #   space, and the value that is displayed on your authentication device.
       #   Required to permanently delete a versioned object if versioning is
       #   configured with MFA delete enabled.
+      #
+      #   When performing the `DeleteObjects` operation on an MFA delete enabled
+      #   bucket, which attempts to delete the specified versioned objects, you
+      #   must include an MFA token. If you don't provide an MFA token, the
+      #   entire request will fail, even if there are non-versioned objects that
+      #   you are trying to delete. If you provide an invalid token, whether
+      #   there are versioned object keys in the request or not, the entire
+      #   Multi-Object Delete request will fail. For information about MFA
+      #   Delete, see [ MFA Delete][1] in the *Amazon S3 User Guide*.
+      #
+      #   <note markdown="1"> This functionality is not supported for directory buckets.
+      #
+      #    </note>
+      #
+      #
+      #
+      #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/Versioning.html#MultiFactorAuthenticationDelete
       # @option options [String] :request_payer
       #   Confirms that the requester knows that they will be charged for the
       #   request. Bucket owners need not specify this parameter in their
-      #   requests. For information about downloading objects from Requester
+      #   requests. If either the source or destination S3 bucket has Requester
+      #   Pays enabled, the requester will pay for corresponding charges to copy
+      #   the object. For information about downloading objects from Requester
       #   Pays buckets, see [Downloading Objects in Requester Pays Buckets][1]
       #   in the *Amazon S3 User Guide*.
       #
+      #   <note markdown="1"> This functionality is not supported for directory buckets.
+      #
+      #    </note>
+      #
       #
       #
       #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/dev/ObjectsinRequesterPaysBuckets.html
@@ -554,25 +813,45 @@ module Aws::S3
       #   Specifies whether you want to delete this object even if it has a
       #   Governance-type Object Lock in place. To use this header, you must
       #   have the `s3:BypassGovernanceRetention` permission.
+      #
+      #   <note markdown="1"> This functionality is not supported for directory buckets.
+      #
+      #    </note>
       # @option options [String] :expected_bucket_owner
-      #   The account ID of the expected bucket owner. If the bucket is owned by
-      #   a different account, the request fails with the HTTP status code `403
-      #   Forbidden` (access denied).
+      #   The account ID of the expected bucket owner. If the account ID that
+      #   you provide does not match the actual owner of the bucket, the request
+      #   fails with the HTTP status code `403 Forbidden` (access denied).
       # @option options [String] :checksum_algorithm
       #   Indicates the algorithm used to create the checksum for the object
-      #   when using the SDK. This header will not provide any additional
-      #   functionality if not using the SDK. When sending this header, there
-      #   must be a corresponding `x-amz-checksum` or `x-amz-trailer` header
-      #   sent. Otherwise, Amazon S3 fails the request with the HTTP status code
-      #   `400 Bad Request`. For more information, see [Checking object
-      #   integrity][1] in the *Amazon S3 User Guide*.
+      #   when you use the SDK. This header will not provide any additional
+      #   functionality if you don't use the SDK. When you send this header,
+      #   there must be a corresponding `x-amz-checksum-algorithm ` or
+      #   `x-amz-trailer` header sent. Otherwise, Amazon S3 fails the request
+      #   with the HTTP status code `400 Bad Request`.
+      #
+      #   For the `x-amz-checksum-algorithm ` header, replace ` algorithm ` with
+      #   the supported algorithm from the following list:
+      #
+      #   * CRC32
+      #
+      #   * CRC32C
+      #
+      #   * SHA1
+      #
+      #   * SHA256
+      #
+      #   For more information, see [Checking object integrity][1] in the
+      #   *Amazon S3 User Guide*.
+      #
+      #   If the individual checksum value you provide through
+      #   `x-amz-checksum-algorithm ` doesn't match the checksum algorithm you
+      #   set through `x-amz-sdk-checksum-algorithm`, Amazon S3 ignores any
+      #   provided `ChecksumAlgorithm` parameter and uses the checksum algorithm
+      #   that matches the provided value in `x-amz-checksum-algorithm `.
       #
       #   If you provide an individual checksum, Amazon S3 ignores any provided
       #   `ChecksumAlgorithm` parameter.
       #
-      #   This checksum algorithm must be the same for all parts and it match
-      #   the checksum value supplied in the `CreateMultipartUpload` request.
-      #
       #
       #
       #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/userguide/checking-object-integrity.html
@@ -589,7 +868,9 @@ module Aws::S3
               version_id: item.id
             }
           end
-          batch[0].client.delete_objects(params)
+          Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
+            batch[0].client.delete_objects(params)
+          end
         end
         nil
       end
