@@ -79,7 +79,7 @@ module Aws::S3
     #   Virtual-hosted-style requests aren't supported. Directory bucket
     #   names must be unique in the chosen Availability Zone. Bucket names
     #   must also follow the format ` bucket_base_name--az_id--x-s3` (for
-    #   example, ` DOC-EXAMPLE-BUCKET--usw2-az2--x-s3`). For information about
+    #   example, ` DOC-EXAMPLE-BUCKET--usw2-az1--x-s3`). For information about
     #   bucket naming restrictions, see [Directory bucket naming rules][2] in
     #   the *Amazon S3 User Guide*
     #
@@ -166,7 +166,7 @@ module Aws::S3
     #   [1]: https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html
     # @return [Bucket]
     def create_bucket(options = {})
-      Aws::Plugins::UserAgent.feature('resource') do
+      Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         @client.create_bucket(options)
       end
       Bucket.new(
@@ -194,7 +194,7 @@ module Aws::S3
     def buckets(options = {})
       batches = Enumerator.new do |y|
         batch = []
-        resp = Aws::Plugins::UserAgent.feature('resource') do
+        resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
           @client.list_buckets(options)
         end
         resp.data.buckets.each do |b|
